# semantic-steve

![semantic-steve banner](https://i.imgur.com/omL5Fax.png)

<div align="left">
	<img src="https://img.shields.io/badge/status-under%20development-orange"/></a>
	<a href="https://github.com/sonnygeorge/semantic-steve/LICENSE"><img src="https://img.shields.io/badge/License-MIT-blue"/></a>
</div>


A semantic wrapper for controlling Minecraft 'Steve'

## Overview

`semantic-steve` is a Python package that provides a semantically intuitive high-level wrapper for controlling an in-game Minecraft bot.

The primary design goal of `semantic-steve` is as an easy-to-understand, yet _generally capable_ controller for **language-model-driven agent systems**. In pursuit of this goal, `semantic-steve` automates away fast-reflex actions (e.g., reactive self-defense) with classical "game AI" (rule-based bot logic) in order to allow language models to focus on high-level strategic decision-making.

`semantic-steve` is not affiliated with Mojang Studios or Microsoft Corporation.